@@ -37,9 +37,14 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     okButton->setFixedWidth(210);
     connect(okButton, SIGNAL(clicked(bool)), this, SLOT(okButtonClicked()));
 
+    //Store last search
+    storelastSearchBox     = new QCheckBox();
+    storelastSearchBox->setText(tr("Store last searched stations"));
+    storelastSearchBox->setChecked(settings->value("storelastsearch", true).toBool());
+
     //Gps early start checkbox
     gpsBox     = new QCheckBox();
-    gpsBox->setText(tr("Start GPS on startup"));
+    gpsBox->setText(tr("Launch GPS on startup"));
     gpsBox->setChecked(settings->value("autostartGPS", true).toBool());
 
     //Gps fallback backend checkbox
@@ -57,6 +62,10 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     item->setTextAlignment(Qt::AlignCenter);
     item->setEditable(false);
     backendModel->appendRow(item);
+    item = new QStandardItem(tr("sbb.ch"));
+    item->setTextAlignment(Qt::AlignCenter);
+    item->setEditable(false);
+    backendModel->appendRow(item);
     QMaemo5ValueButton *backendButton = new QMaemo5ValueButton(tr("Databackend"));
     backendButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
     backendSelector = new QMaemo5ListPickSelector;
@@ -71,6 +80,9 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     } else if (backendType == "parserMvvDe")
     {
             backendSelector->setCurrentIndex(1);
+    } else if (backendType == "parserSbbCh")
+    {
+            backendSelector->setCurrentIndex(2);
     } else
     {
        //fallback is bahn.de
@@ -83,6 +95,7 @@ configDialog::configDialog(QSettings *mainSettings, QWidget *mainParent)
     vLayout->setSpacing(0);
     vLayout->addWidget(gpsBox);
     vLayout->addWidget(gpsBackendBox);
+    vLayout->addWidget(storelastSearchBox);
     vLayout->addWidget(backendButton);
     vContainer->setLayout(vLayout);
 
@@ -99,6 +112,7 @@ void configDialog::okButtonClicked()
 {
     settings->setValue("autostartGPS", gpsBox->isChecked());
     settings->setValue("openstreetmapfallback", gpsBackendBox->isChecked());
+    settings->setValue("storelastsearch", storelastSearchBox->isChecked());
 
     if (backendSelector->currentIndex() == 0)
     {
@@ -106,6 +120,9 @@ void configDialog::okButtonClicked()
     } else if (backendSelector->currentIndex() == 1)
     {
         settings->setValue("backend", "parserMvvDe");
+    } else if (backendSelector->currentIndex() == 2)
+    {
+        settings->setValue("backend", "parserSbbCh");
     } else
     {
         settings->setValue("backend", "parserMobileBahnDe");
