@@ -19,6 +19,7 @@
 */
 
 #include <QtGui/QApplication>
+#include <QtDBus>
 #include "mainwindow.h"
 
 int main(int argc, char *argv[])
@@ -26,6 +27,24 @@ int main(int argc, char *argv[])
     QApplication a(argc, argv);
     MainWindow w;
 
+    if (!QDBusConnection::sessionBus().isConnected())
+    {
+        qWarning("Cannot connect to the D-Bus session bus.");
+        exit(1);
+    }
+
+    if (!QDBusConnection::sessionBus().registerService("com.nokia.fahrplan"))
+    {
+        qWarning("%s", qPrintable(QDBusConnection::sessionBus().lastError().message()));
+        exit(2);
+    }
+
+    if (!QDBusConnection::sessionBus().registerObject("/com/nokia/fahrplan", &w, QDBusConnection::ExportScriptableSlots))
+    {
+        qWarning("%s", qPrintable(QDBusConnection::sessionBus().lastError().message()));
+        exit(3);
+    }
+
 #if defined(Q_WS_S60)
     w.showMaximized();
 #else
