@@ -21,7 +21,7 @@
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent)
-    : QMainWindow(parent), resultWindow(0)
+    : QMainWindow(parent), resultWindow(0), detailsWindow(0)
 {
     QWidget *mainWidget = new QWidget;
     QGtkStyle *gtkStyle = new QGtkStyle();
@@ -157,8 +157,8 @@ MainWindow::MainWindow(QWidget *parent)
     if (settings->value("firstLaunch", "") != APP_VER)
     {
         QMessageBox::about(this,
-                           tr("Welcome to a new version of fahrplan this is new"),
-                           tr("- added sbb.ch backend<br>- you now can store the last 20 searched stations and quickly select them.<br>- some small other fixes/improvements")
+                           tr("Welcome to a new version of fahrplan this has changed"),
+                           tr("- gps fixes for bahn.de backend<br>- if you in details screen youre able to add the infos to n900 default calendar<br>- optimized usage of OSM gps interface.")
                            );
 
         settings->setValue("firstLaunch", APP_VER);
@@ -233,6 +233,86 @@ void MainWindow::stationArrivalClicked()
     selectDialog->show();
 }
 
+void MainWindow::alarmButtonClicked()
+{
+    CMulticalendar *multiCalendar = CMulticalendar::MCInstance();
+
+    CCalendar *calendar = multiCalendar->getDefaultCalendar();
+
+    QString title       = tr("Journey: ") + lastSearchDetails.items.first().fromStation + tr(" to ") + lastSearchDetails.items.last().toStation;
+    QString description = lastSearchDetails.items.first().fromStation + tr(" to ") + lastSearchDetails.items.last().toStation + "\n";
+
+    if (lastSearchDetails.info != "")
+    {
+        description.append(lastSearchDetails.info + "\n");
+    }
+    if (lastSearchDetails.duration != "")
+    {
+        description.append(tr("Duration: ") + lastSearchDetails.duration + "\n");
+    }
+
+    description.append("\n");
+
+    foreach(DetailResultItem item, lastSearchDetails.items)
+    {
+        if (item.train != "")
+        {
+            description.append(item.train + "\n");
+        }
+
+        description.append( item.fromStation );
+
+        if (item.fromInfo != "")
+        {
+            description.append(" - " + item.fromInfo + "\n");
+        } else
+        {
+            description.append("\n");
+        }
+
+        description.append( item.toStation );
+
+        if (item.toInfo != "")
+        {
+            description.append(" - " + item.toInfo);
+        }
+
+        if (item.info != "")
+        {
+            description.append("\n" + item.info);
+        }
+
+        description.append("\n\n");
+    }
+
+    description.append("\n\n(added by fahrplan app, please recheck informations before travel.)");
+
+    title       = fahrplanUtils::removeUmlauts(title);
+    description = fahrplanUtils::removeUmlauts(description);
+
+    QDateTime tsFrom = lastSearchDetails.items.first().fromTime;
+    QDateTime tsTo   = lastSearchDetails.items.last().toTime;
+
+    if (tsFrom.toTime_t() < QDateTime::currentDateTime().toTime_t())
+    {
+        QMaemo5InformationBox::information(this, "<br>Entry is in the past!<br>", QMaemo5InformationBox::DefaultTimeout);
+        return;
+    } else
+    {
+        qDebug() <<title;
+        qDebug() <<tsFrom.toString("dd.MM.yyyy hh:mm");
+        qDebug() <<tsTo.toString("dd.MM.yyyy hh:mm");
+        qDebug() <<description;
+
+        CEvent *pEvent = new CEvent(title.toStdString(), description.toStdString(), "", tsFrom.toTime_t(), tsTo.toTime_t());
+        int errorCode = 0;
+
+        multiCalendar->addEvent(pEvent, calendar->getCalendarId(), errorCode);
+
+        QMaemo5InformationBox::information(this, "<br>Entry added to your default calendar.<br>", QMaemo5InformationBox::DefaultTimeout);
+    }
+}
+
 void MainWindow::aboutButtonClicked()
 {
     QString version = APP_VER;
@@ -293,17 +373,21 @@ void MainWindow::showDetailsWindow()
     connect(detailsWindow, SIGNAL(destroyed(QObject*)),
             this, SLOT(windowDestroyed(QObject*)));
 
+    //Alarm Menu Button
+    QAction *alarmAct = new QAction(tr("Add to calendar"), this);
+    connect(alarmAct, SIGNAL(triggered()), this, SLOT(alarmButtonClicked()));
+    detailsWindow->menuBar()->addAction(alarmAct);
 
     QWidget *itemsWidget = new QWidget;
     QVBoxLayout *itemLayout = new QVBoxLayout;
     itemLayout->setMargin(10);
     QScrollArea *scrollArea = new QScrollArea;
 
-    /*
+/*
     qDebug() <<"Result:";
     qDebug() <<lastSearchDetails.duration;
     qDebug() <<lastSearchDetails.info;
-    */
+*/
 
     foreach(DetailResultItem item, lastSearchDetails.items)
     {
@@ -350,7 +434,6 @@ void MainWindow::showDetailsWindow()
         line->setPalette(palette);
 
         itemLayout->addWidget(line);
-
 /*
         qDebug() <<"Item:";
         qDebug() <<item.train;
@@ -359,7 +442,7 @@ void MainWindow::showDetailsWindow()
         qDebug() <<item.toInfo;
         qDebug() <<item.fromInfo;
         qDebug() <<item.info;
-        */
+*/
     }
 
     //Creating result data
