@@ -36,6 +36,11 @@
 #include <qgeopositioninfo.h>
 #include <qgeopositioninfosource.h>
 
+#include <calendar-backend/CCalendar.h>
+#include <calendar-backend/CMulticalendar.h>
+#include <calendar-backend/CEvent.h>
+#include <calendar-backend/CAlarm.h>
+
 #include "parser_abstract.h"
 #include "parser_mobilebahnde.h"
 #include "parser_mvvde.h"
@@ -44,7 +49,7 @@
 #include "configdialog.h"
 #include "fahrplanutils.h"
 
-#define APP_VER "0.0.13"
+#define APP_VER "0.0.14"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -71,6 +76,7 @@ public slots:
 private slots:
     void searchButtonClicked(bool checked = false);
     void aboutButtonClicked();
+    void alarmButtonClicked();
     void settingsButtonClicked();
     void earlierButtonClicked();
     void laterButtonClicked();
