@@ -236,32 +236,53 @@ DetailResultInfo parserMobileBahnDe::getJourneyDetailsData(QString queryUrl)
             if (stationResults.count() == 2)
             {
                 DetailResultItem item;
-                item.fromStation = stationResults[0];
-                item.toStation   = stationResults[1];
+                item.fromStation = stationResults[0].trimmed();
+                item.toStation   = stationResults[1].trimmed();
                 if (trainnrResults.count() > 0)
                 {
-                    item.train = trainnrResults[0];
+                    item.train = trainnrResults[0].trimmed();
                 }
 
                 QString tmp = txtResults.join(" ");
                 tmp.replace("  ", " ");
                 tmp.replace("\n", " ");
 
-                //qDebug() <<tmp;
-
                 //Check and Parse departure and arrival Times
                 QRegExp tmpRegexp = QRegExp("(dep) (.+) on (.*) (arr) (.+) on (.*) ");
                 tmpRegexp.setMinimal(true);
                 tmpRegexp.indexIn(tmp);
+
                 if (tmpRegexp.cap(0) != "")
                 {
                     if (tmpRegexp.cap(1) == "dep")
                     {
-                        item.fromInfo = tmpRegexp.cap(2) + " on " + tmpRegexp.cap(3);
+                        item.fromInfo = tmpRegexp.cap(2).trimmed() + " on " + tmpRegexp.cap(3).trimmed();
+
+                        QRegExp tmpRegexp2 = QRegExp("(\\d\\d:\\d\\d)");
+                        tmpRegexp2.setMinimal(true);
+                        tmpRegexp2.indexIn(tmpRegexp.cap(2).trimmed());
+
+                        QDate fromDate = QDate::fromString(tmpRegexp.cap(3).trimmed(), "dd.MM.yy");
+                        QTime fromTime = QTime::fromString(tmpRegexp2.cap(1).trimmed(), "hh:mm");
+
+                        fromDate = fromDate.addYears(100); //default is 1900 so we add 100years
+                        item.fromTime.setDate(fromDate);
+                        item.fromTime.setTime(fromTime);
                     }
                     if (tmpRegexp.cap(4) == "arr")
                     {
-                        item.toInfo = tmpRegexp.cap(5) + " on " + tmpRegexp.cap(6);
+                        item.toInfo = tmpRegexp.cap(5).trimmed() + " on " + tmpRegexp.cap(6).trimmed();
+
+                        QRegExp tmpRegexp2 = QRegExp("(\\d\\d:\\d\\d)");
+                        tmpRegexp2.setMinimal(true);
+                        tmpRegexp2.indexIn(tmpRegexp.cap(5).trimmed());
+
+                        QDate toDate = QDate::fromString(tmpRegexp.cap(6).trimmed(), "dd.MM.yy");
+                        QTime toTime = QTime::fromString(tmpRegexp2.cap(1).trimmed(), "hh:mm");
+
+                        toDate = toDate.addYears(100); //default is 1900 so we add 100years
+                        item.toTime.setDate(toDate);
+                        item.toTime.setTime(toTime);
                     }
                 } else
                 {
@@ -501,12 +522,19 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
 
 QStringList parserMobileBahnDe::getStationsByGPS(qreal latitude, qreal longitude)
 {
+    //We must format the lat and longitude to have the ??.?????? format.
     QString zeros      = "0";
-    QString sLongitude = QString::number(longitude).replace(QChar('.'), "");
-    QString sLatitude  = QString::number(latitude).replace(QChar('.'), "");
+    QString sLongitude = QString::number(longitude).append(zeros.repeated(6));
+    QString sLatitude  = QString::number(latitude).append(zeros.repeated(6));
 
-    sLongitude.append(zeros.repeated(8 - sLongitude.count()));
-    sLatitude.append(zeros.repeated(8 - sLatitude.count()));
+    QRegExp regexp = QRegExp("(\\d*)\\.(\\d\\d\\d\\d\\d\\d)(\\d*)");
+    regexp.setMinimal(true);
+
+    regexp.indexIn(sLongitude);
+    sLongitude = regexp.cap(1) + regexp.cap(2);
+
+    regexp.indexIn(sLatitude);
+    sLatitude = regexp.cap(1) + regexp.cap(2);
 
     QString fullUrl = "http://mobile.bahn.de/bin/mobil/query.exe/eox?rt=1&use_realtime_filter=1&stationNear=1&look_x=" +
                       sLongitude +
@@ -548,6 +576,8 @@ QStringList parserMobileBahnDe::getStationsByGPS(qreal latitude, qreal longitude
 
     delete filebuffer;
 
+    result.removeDuplicates();
+
     return result;
 }
 
