@@ -238,7 +238,7 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
     QXmlQuery query;
     query.bindVariable("path", &readBuffer);
     //Query for more than one result
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='time-0'][@class!='prognosis']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='time-0'][@class!='prognosis'][@class!='prognosis last']/string()");
     QStringList timelinkResults;
     if (!query.evaluateTo(&timelinkResults))
     {
@@ -285,25 +285,83 @@ DetailResultInfo parserSbbCh::getJourneyDetailsData(QString queryUrl)
         qDebug() << "parserSbbCh::getJourneyDetailsData - Query 6 Failed";
     }
 
-/*
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/table/tr/td/table/tr/td[@headers='date-0']/string()");
+
+    QStringList dateResults;
+    if (!query.evaluateTo(&dateResults))
+    {
+        qDebug() << "parserSbbCh::parseJourneyData - Query 7 Failed";
+    }
+
+    /*
     qDebug() <<infoResults;
     qDebug() <<fromToResults;
     qDebug() <<timelinkResults;
     qDebug() <<platformResults;
     qDebug() <<trainsResults;
     qDebug() <<durationResults;
-*/
+    qDebug() <<dateResults;
+    */
+
     DetailResultInfo result;
 
+    QString lastDate = "";
+
     for(int i = 0; i < trainsResults.count(); i++)
     {
         DetailResultItem item;
 
-        item.fromStation = fromToResults[i * 2];
-        item.fromInfo    = timelinkResults[(i * 4) + 1] + " Pl." + platformResults[(i*2)];
-        item.toStation   = fromToResults[(i * 2) + 1];
-        item.toInfo      = timelinkResults[(i * 4) + 3] + " Pl." + platformResults[(i*2) + 1];
-        item.train       = trainsResults[i];
+        item.fromStation = fromToResults[i * 2].trimmed();
+        item.fromInfo    = timelinkResults[(i * 4) + 1].trimmed();
+        if (platformResults[(i*2)].trimmed() != "")
+        {
+            item.fromInfo.append(" Pl." + platformResults[(i*2)].trimmed());
+        }
+
+        item.toStation   = fromToResults[(i * 2) + 1].trimmed();
+        item.toInfo      = timelinkResults[(i * 4) + 3].trimmed();
+        if (platformResults[(i*2) + 1].trimmed() != "")
+        {
+            item.toInfo.append(" Pl." + platformResults[(i*2) + 1].trimmed());
+        }
+        item.train       = trainsResults[i].trimmed();
+
+        if (dateResults[i * 2].trimmed() != "")
+        {
+            QRegExp tmpRegexp = QRegExp("(.*), (\\d\\d.\\d\\d.\\d\\d)");
+            tmpRegexp.setMinimal(true);
+            tmpRegexp.indexIn(dateResults[i * 2].trimmed());
+            lastDate = tmpRegexp.cap(2);
+        }
+
+        if (lastDate != "")
+        {
+            QDate fromDate = QDate::fromString(lastDate, "dd.MM.yy");
+            QTime fromTime = QTime::fromString(timelinkResults[(i * 4) + 1].trimmed(), "hh:mm");
+
+            fromDate = fromDate.addYears(100); //default is 1900 so we add 100years
+            item.fromTime.setDate(fromDate);
+            item.fromTime.setTime(fromTime);
+        }
+
+        if (dateResults[(i * 2) + 1].trimmed() != "")
+        {
+            QRegExp tmpRegexp = QRegExp("(.*), (\\d\\d.\\d\\d.\\d\\d)");
+            tmpRegexp.setMinimal(true);
+            tmpRegexp.indexIn(dateResults[(i * 2) + 1].trimmed());
+            lastDate = tmpRegexp.cap(2);
+        }
+
+        if (lastDate != "")
+        {
+            QDate toDate = QDate::fromString(lastDate, "dd.MM.yy");
+            QTime toTime = QTime::fromString(timelinkResults[(i * 4) + 3].trimmed(), "hh:mm");
+
+            toDate = toDate.addYears(100); //default is 1900 so we add 100years
+            item.toTime.setDate(toDate);
+            item.toTime.setTime(toTime);
+        }
+
         result.items.append(item);
     }
 
@@ -322,7 +380,7 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
     QRegExp regexp = QRegExp("<form name=\"tp_results_form\" action=\"(.*)\" method=\"post\" style=\"display:inline;\">(.*)<table cellspacing=\"0\" class=\"hafas-content hafas-tp-result-overview\">(.*)</table>(.*)<table class=\"hafas-content\"");
     regexp.setMinimal(true);
 
-    regexp.indexIn(filebuffer->buffer());
+    regexp.indexIn(data);
 
     QString element = "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<body>\n<table>" + regexp.cap(3) + "</table>\n</body>\n</html>\n";
 
