@@ -28,8 +28,8 @@
 #include <qgeopositioninfo.h>
 #include <qgeopositioninfosource.h>
 #include <backupgpsopenstreetmap.h>
-
-#include "parser_mobilebahnde.h"
+#include "fahrplanutils.h"
+#include "parser_abstract.h"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -47,10 +47,10 @@ public slots:
     void searchButtonClicked(bool checked);
     void gpsButtonClicked(bool checked);
     void stationSelected(QString value);
-    void searchReturnPressed();
 
 private:
-    QLineEdit   *searchbox;
+    QComboBox   *searchboxCombo;
+    QLineEdit   *searchboxText;
     QPushButton *gpsButton;
     QPushButton *searchButton;
     QMaemo5ValueButton *mainSender;
